==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/SourceFile__24InnerClass.h <==
// class org.dellroad.jc.cgen.SourceFile$InnerClass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 840d7f44ecbe547d org_dellroad_jc_cgen_SourceFile__24InnerClass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_SourceFile__24InnerClass_H_
#define _JC_org_dellroad_jc_cgen_SourceFile__24InnerClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object;

typedef const struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods	org_dellroad_jc_cgen_SourceFile__24InnerClass;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs {
	struct _jc_soot_SootClass$object	*inner;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs {
    _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs	org_dellroad_jc_cgen_SourceFile__24InnerClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs {
	jint	flags;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs	org_dellroad_jc_cgen_SourceFile__24InnerClass;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object {
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_SourceFile__24InnerClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_SourceFile__24InnerClass_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/SourceFile__24InnerClass.h <==
// class org.dellroad.jc.cgen.SourceFile$InnerClass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 840d7f44ecbe547d org_dellroad_jc_cgen_SourceFile__24InnerClass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_SourceFile__24InnerClass_H_
#define _JC_org_dellroad_jc_cgen_SourceFile__24InnerClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object;

typedef const struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vmethods	org_dellroad_jc_cgen_SourceFile__24InnerClass;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs {
	struct _jc_soot_SootClass$object	*inner;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs {
    _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_refs	org_dellroad_jc_cgen_SourceFile__24InnerClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs {
	jint	flags;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$sub_nonrefs	org_dellroad_jc_cgen_SourceFile__24InnerClass;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$object {
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$vtype _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_SourceFile__24InnerClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_SourceFile__24InnerClass$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_SourceFile__24InnerClass_H_ */
